@@ -42,7 +42,33 @@ cn_digits = dict({
     "20":"二十",
     "21":"二十一",
     "22":"二十二",
-    "23":"二十三"
+    "23":"二十三",
+    "24":"二十四",
+    "25":"二十五",
+    "26":"二十六",
+    "27":"二十七",
+    "28":"二十八",
+    "29":"二十九",
+    "30":"三十",
+    "31":"三十一",
+    "32":"三十二",
+    "33":"三十三",
+    "34":"三十四",
+    "35":"三十五",
+    "36":"三十六",
+    "37":"三十七",
+    "38":"三十八",
+    "39":"三十九",
+    "40":"四十",
+    "41":"四十一",
+    "42":"四十二",
+    "43":"四十三",
+    "44":"四十四",
+    "45":"四十五",
+    "46":"四十六",
+    "47":"四十七",
+    "48":"四十八",
+    "49":"四十九",
 })
 
 # figures
@@ -50,8 +76,8 @@ matched_figure = lambda x: x.strip().startswith("![") and x.strip().endswith(")"
 matched_figure_caption = lambda x: x.strip()[x.strip().index("![") + 2:x.strip().index("]("):]
 
 # tables
-matched_table = lambda x: x.strip().startswith("<mkc:table>") and x.strip().endswith("</mkc:table>")
-matched_table_caption = lambda x: x.strip()[11:x.strip().index("</mkc:table>"):]
+matched_table = lambda x: x.strip().startswith("<!-- markup:table-caption") and x.strip().endswith("-->")
+matched_table_caption = lambda x: x.strip()[26:len(x.strip()) - 3:]
 
 class TableOfContents(Module):
     """
@@ -118,9 +144,6 @@ class TableOfContents(Module):
                 break
         return figure_index_chapter
 
-
-
-
     def transform(self, data):
         transforms = []
 
@@ -138,6 +161,7 @@ class TableOfContents(Module):
         tables = {}
 
         infencedcodeblock = False
+        infencedcodecount = 0
 
         # iterate through the document looking for markers and headers
         linenum = 0
@@ -156,18 +180,21 @@ class TableOfContents(Module):
             </w:p>
             ```
             '''
+
+            # Fenced code blocks (Github-flavored markdown)
+            counted = line.count("```")
+            # print("infencedcodecount", infencedcodecount, counted, line)
+            infencedcodecount = infencedcodecount + counted
+            # print("infencedcodecount", infencedcodecount)
+            if (infencedcodecount % 2) == 0 :
+                infencedcodeblock = False
+            else:
+                infencedcodeblock = True
+
             if striped.startswith("```") or striped.startswith("<w:") or striped.startswith("</w:"):
                 linenum = linenum + 1
                 continue
 
-            # Fenced code blocks (Github-flavored markdown)
-            match = fencedcodere.search(line)
-            if match:
-                if infencedcodeblock:
-                    infencedcodeblock = False
-                else:
-                    infencedcodeblock = True
-
             # !TOC markers
             match = tocre.search(line)
             if match:
@@ -178,10 +205,12 @@ class TableOfContents(Module):
                     tocdepth = max(depth, tocdepth)
                 toclines.append(linenum)
 
+                print("[INFO] TOC is turn on, max tocdepth %d" %  tocdepth)
+
                 h1lang = match.group(2)
                 if h1lang is not None:
                     h1lang = h1lang.strip().lower()
-                    print("TOC h1 in lang: %s" %  h1lang)
+                    print("[INFO] TOC generate h1 in lang %s" %  h1lang)
                     if h1lang in ["en", "cn"]:
                         toch1lang = h1lang
                     else:
@@ -219,7 +248,6 @@ class TableOfContents(Module):
             # tables
             if matched_table(line):
                 table_cap = matched_table_caption(line)
-                # print("table_cap", table_cap, depth, linenum)
                 tables[linenum] = ("", table_cap) # set index as emtpy string, resolve later.
 
             lastline = line
@@ -315,7 +343,7 @@ class TableOfContents(Module):
             else:
                 figure_index_num = figure_index_num + 1
 
-            transforms.append(Transform(linenum, "swap", data[linenum].replace("![%s](" %  list(figures[linenum])[1], "![%s %s %s](" %  (self.resolve_figure_marker(toch1lang),
+            transforms.append(Transform(linenum, "swap", data[linenum].replace("![%s](" %  list(figures[linenum])[1], "![%s%s %s](" %  (self.resolve_figure_marker(toch1lang),
                                                                                                                                          "%d.%d" % (figure_index_curr, figure_index_num) if figure_index_curr != 0 else "%d" % (figure_index_num - 1),
                                                                                                                                          list(figures[linenum])[1]), 1)))
 
@@ -323,17 +351,19 @@ class TableOfContents(Module):
         table_index_num = 1
         table_index_pre = 0
         for linenum in tables.keys():
+            # print("fff linenum", linenum)
             table_index_curr = self.resolve_chatper_index(linenum, transforms)
+            # print("table_index_curr", table_index_curr, ", table_index_pre", table_index_pre)
             if table_index_curr != table_index_pre:
                 table_index_num = 1
                 table_index_pre = table_index_curr
             else:
                 table_index_num = table_index_num + 1
 
-            transforms.append(Transform(linenum, "swap", "Table: %s %s %s\n" % (
-                self.resolve_table_marker(toch1lang),
+            swap_content = (self.resolve_table_marker(toch1lang),
                 "%d.%d" % (table_index_curr, table_index_num) if table_index_curr != 0 else "%d" % (table_index_num - 1),
-                list(tables[linenum])[1]
-            )))
+                list(tables[linenum])[1])
+            # print("SWAP TABLE", swap_content)
+            transforms.append(Transform(linenum, "swap", "Table: %s%s %s\n" % swap_content))
 
         return transforms
